@@ -1,8 +1,9 @@
-__version__ = "0.0.13"
+__version__ = "0.0.14"
 __all__ = [
     "allchecks",
     "checkcrt",
     "checkcsr",
+    "checkdnskey",
     "checkjwk",
     "checkprivkey",
     "checkpubkey",
@@ -13,17 +14,8 @@ __all__ = [
     "scanssh",
     "warningchecks",
 ]
-from .checks import (
-    allchecks,
-    checkcrt,
-    checkcsr,
-    checkprivkey,
-    checkpubkey,
-    checkrsa,
-    checksshpubkey,
-    defaultchecks,
-    detectandcheck,
-    warningchecks,
-)
+from .checks import (allchecks, checkcrt, checkcsr, checkprivkey, checkpubkey, checkrsa,
+                     checksshpubkey, defaultchecks, detectandcheck, warningchecks)
+from .dnssec import checkdnskey
 from .jwk import checkjwk
 from .scanssh import scanssh
